@@ -30,6 +30,11 @@ def pass_list(counter, length):
 
 
 def ir_mobile_generator(prefix):
+    """
+    iranian mobile phone generate
+    :param prefix:
+    :return:
+    """
     mobile_number_list = []
     for num in range(1111111, 9999999):
         mobile_number_list.append(prefix + str(num))
