@@ -35,7 +35,7 @@ def error_writer(error_content, file_name):
 
         error_log_writer = open(log_file_name, mode_write)
         error_log_writer.write(
-            "[ " + get_current_date_time + " ]" + " - " + error_content.__str__() + f"Available: {get_size(svmem.available)} " + " \n")
+            "[ " + get_current_date_time + " ]" + " - " + error_content.__str__() + f"  [  Available Memory Usage: {get_size(svmem.available)} ] " + f" [ Total CPU Usage: {psutil.cpu_percent()}% ] " + " \n")
         error_log_writer.close()
     except Exception as e:
         print(e.__str__())
